@@ -230,7 +230,7 @@ gg_bar <- function(data,
     y_limits <- c(min(y_breaks), max(y_breaks))
     
     plot <- plot +
-      scale_y_continuous(expand = y_expand, breaks = y_breaks, limits = y_limits, labels = y_labels, oob = scales::oob_squish)
+      scale_y_continuous(expand = y_expand, breaks = y_breaks, limits = y_limits, labels = y_labels)
   })
   
   if (y_zero_line == TRUE) {
@@ -508,7 +508,7 @@ gg_bar_col <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE, format_fun = col_labels)))
         
         col_labels <- sv_interval_labels_chr
@@ -517,7 +517,7 @@ gg_bar_col <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE)))
       }
       
@@ -628,7 +628,7 @@ gg_bar_col <- function(data,
     y_limits <- c(min(y_breaks), max(y_breaks))
     
     plot <- plot +
-      scale_y_continuous(expand = y_expand, breaks = y_breaks, limits = y_limits, labels = y_labels, oob = scales::oob_squish)
+      scale_y_continuous(expand = y_expand, breaks = y_breaks, limits = y_limits, labels = y_labels)
   })
   
   if (y_zero_line == TRUE) {
@@ -957,7 +957,7 @@ gg_bar_facet <- function(data,
       y_limits <- c(min(y_breaks), max(y_breaks))
       
       plot <- plot +
-        scale_y_continuous(expand = y_expand, breaks = y_breaks, limits = y_limits, labels = y_labels, oob = scales::oob_squish)
+        scale_y_continuous(expand = y_expand, breaks = y_breaks, limits = y_limits, labels = y_labels)
     })
   }
   else if (facet_scales %in% c("free", "free_y")) {
@@ -1252,7 +1252,7 @@ gg_bar_col_facet <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE, format_fun = col_labels)))
         
         col_labels <- sv_interval_labels_chr
@@ -1261,7 +1261,7 @@ gg_bar_col_facet <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE)))
       }
       
@@ -1369,7 +1369,7 @@ gg_bar_col_facet <- function(data,
       y_limits <- c(min(y_breaks), max(y_breaks))
       
       plot <- plot +
-        scale_y_continuous(expand = y_expand, breaks = y_breaks, limits = y_limits, labels = y_labels, oob = scales::oob_squish)
+        scale_y_continuous(expand = y_expand, breaks = y_breaks, limits = y_limits, labels = y_labels)
     })
   }
   else if (facet_scales %in% c("free", "free_y")) {
