@@ -4,7 +4,7 @@
 #' @param x_var Generally an unquoted numeric variable to be on the x scale. However if stat = "identity" is selected, a list-column with min, lower, middle, upper, and max variable names.
 #' @param y_var Unquoted categorical variable to be on the y scale (i.e. character, factor, or logical). Required input.
 #' @param pal Character vector of hex codes. 
-#' @param alpha_fill The opacity of the fill. Defaults to 0.2. 
+#' @param alpha_fill The opacity of the fill. Defaults to 1. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param size_line The size of the outlines of violins. Defaults to 0.5.
 #' @param size_width Width of boxes. Defaults to 0.75.
@@ -50,7 +50,7 @@ gg_hviolin <- function(data,
                        x_var = NULL,
                        y_var,
                        pal = pal_viridis_reorder(1),
-                       alpha_fill = 0.2,
+                       alpha_fill = 1,
                        alpha_line = 1,
                        size_line = 0.5,
                        size_width = 0.75,
@@ -204,7 +204,7 @@ gg_hviolin <- function(data,
 #' @param pal Character vector of hex codes. 
 #' @param pal_na The hex code or name of the NA colour to be used.
 #' @param pal_rev Reverses the palette. Defaults to FALSE.
-#' @param alpha_fill The opacity of the fill. Defaults to 0.2. 
+#' @param alpha_fill The opacity of the fill. Defaults to 1. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param size_line The size of the outlines of violins. Defaults to 0.5.
 #' @param size_width Width of boxes. Defaults to 0.75.
@@ -261,7 +261,7 @@ gg_hviolin_col <- function(data,
                            pal = NULL,
                            pal_na = "#7F7F7F",
                            pal_rev = FALSE,
-                           alpha_fill = 0.2,
+                           alpha_fill = 1,
                            alpha_line = 1,
                            size_line = 0.5,
                            size_width = 0.75,
@@ -484,7 +484,7 @@ gg_hviolin_col <- function(data,
 #' @param y_var Unquoted categorical variable to be on the y scale (i.e. character, factor, or logical). Required input.
 #' @param facet_var Unquoted categorical variable to facet the data by. Required input.
 #' @param pal Character vector of hex codes. 
-#' @param alpha_fill The opacity of the fill. Defaults to 0.2. 
+#' @param alpha_fill The opacity of the fill. Defaults to 1. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param size_line The size of the outlines of violins. Defaults to 0.5.
 #' @param size_width Width of boxes. Defaults to 0.75.
@@ -538,7 +538,7 @@ gg_hviolin_facet <- function(data,
                              y_var,
                              facet_var,
                              pal = pal_viridis_reorder(1),
-                             alpha_fill = 0.2,
+                             alpha_fill = 1,
                              alpha_line = 1,
                              size_line = 0.5,
                              size_width = 0.75,
@@ -712,7 +712,7 @@ gg_hviolin_facet <- function(data,
 #' @param pal Character vector of hex codes. 
 #' @param pal_na The hex code or name of the NA colour to be used.
 #' @param pal_rev TRUE or FALSE of whether to reverse the pal.
-#' @param alpha_fill The opacity of the fill. Defaults to 0.2. 
+#' @param alpha_fill The opacity of the fill. Defaults to 1. 
 #' @param alpha_line The opacity of the outline. Defaults to 1. 
 #' @param size_line The size of the outlines of violins. Defaults to 0.5.
 #' @param size_width Width of boxes. Defaults to 0.75.
@@ -777,7 +777,7 @@ gg_hviolin_col_facet <- function(data,
                                  pal = NULL,
                                  pal_na = "#7F7F7F",
                                  pal_rev = FALSE,
-                                 alpha_fill = 0.2,
+                                 alpha_fill = 1,
                                  alpha_line = 1,
                                  size_line = 0.5,
                                  size_width = 0.75,
