@@ -431,7 +431,7 @@ gg_point_col <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE, format_fun = col_labels)))
         
         col_labels <- sv_interval_labels_chr
@@ -440,7 +440,7 @@ gg_point_col <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE)))
       }
       
@@ -1086,7 +1086,7 @@ gg_point_col_facet <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE, format_fun = col_labels)))
         
         col_labels <- sv_interval_labels_chr
@@ -1095,7 +1095,7 @@ gg_point_col_facet <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE)))
       }
       
