@@ -220,7 +220,7 @@ gg_tile_col <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE, format_fun = col_labels)))
         
         col_labels <- sv_interval_labels_chr
@@ -229,7 +229,7 @@ gg_tile_col <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE)))
       }
       
@@ -600,7 +600,7 @@ gg_tile_col_facet <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE, format_fun = col_labels)))
         
         col_labels <- sv_interval_labels_chr
@@ -609,7 +609,7 @@ gg_tile_col_facet <- function(data,
         data <- data %>%
           dplyr::mutate(
             dplyr::across(!!col_var, 
-                          ~ cut_format(.x, col_cuts,
+                          ~ kimisc::cut_format(.x, col_cuts,
                                        right = col_intervals_right, include.lowest = TRUE, dig.lab = 50, ordered_result = TRUE)))
       }
       
